@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: code128.pm,v 1.4 2004/06/07 19:44:44 fredo Exp $
+#   $Id: code128.pm,v 1.6 2004/06/15 09:14:54 fredo Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::XObject::Form::BarCode::code128;
@@ -44,7 +44,7 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Resource::XObject::Form::BarCode );
 
-    ( $VERSION ) = '$Revision: 1.4 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/07 19:44:44 $
+    ( $VERSION ) = '$Revision: 1.6 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/15 09:14:54 $
 
 }
 
@@ -235,6 +235,12 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: code128.pm,v $
+    Revision 1.6  2004/06/15 09:14:54  fredo
+    removed cr+lf
+
+    Revision 1.5  2004/06/11 12:56:29  fredo
+    fixed encode bug
+
     Revision 1.4  2004/06/07 19:44:44  fredo
     cleaned out cr+lf for lf
 
